@@ -53,7 +53,7 @@ extern const float d65_white[3];
 #define SQR(x) ((x)*(x))
 #define LIM(x,min,max) MAX(min,MIN(x,max))
 #define ULIM(x,y,z) ((y) < (z) ? LIM(x,y,z) : LIM(x,z,y))
-#define CLIP(x) LIM(x,0,65535)
+#define CLIP(x) LIM((int)(x),0,65535)
 #define SWAP(a,b) { a ^= b; a ^= (b ^= a); }
 
 /*
@@ -614,7 +614,6 @@ void CLASS xtrans_interpolate_INDI(ushort(*image)[4], const unsigned filters,
     dcraw_message(dcraw, DCRAW_VERBOSE, _("%d-pass X-Trans interpolation...\n"), passes); /*NKBJ*/
 
     cielab_INDI(0, 0, colors, rgb_cam);
-    border_interpolate_INDI(height, width, image, filters, colors, 6, hh);
     ndir = 4 << (passes > 1);
 
     /* Map a green hexagon around each non-green pixel and vice versa:      */
@@ -846,6 +845,7 @@ void CLASS xtrans_interpolate_INDI(ushort(*image)[4], const unsigned filters,
         }
         free(buffer);
     } /* _OPENMP */
+    border_interpolate_INDI(height, width, image, filters, colors, 8, hh);
 }
 
 /*
