@@ -219,17 +219,20 @@ extern "C" {
     public:
         GObject **gobject;
         GtkButton *button;
-        explicit _UFWidgetData(int size = 1) {
+        explicit _UFWidgetData(int size = 1)
+        {
             if (size != 0)
                 gobject = g_new0(GObject *, size);
             else
                 gobject = NULL;
             button = NULL;
         }
-        ~_UFWidgetData() {
+        ~_UFWidgetData()
+        {
             g_free(gobject);
         }
-        GtkAdjustment *adjustment(int index) {
+        GtkAdjustment *adjustment(int index)
+        {
             return GTK_ADJUSTMENT(gobject[index]);
         }
     };
@@ -534,6 +537,14 @@ extern "C" {
         return false;
     }
 
+    static bool _ufarray_entry_activate(GtkWidget *entry, UFObject *object)
+    {
+        UFArray &array = *object;
+        array.Set(gtk_entry_get_text(GTK_ENTRY(entry)));
+        _ufobject_reset_button_state(object);
+        return false;
+    }
+
     GtkWidget *_ufarray_combo_box_new(UFObject *object, GtkWidget *combo)
     {
         UFArray &array = *object;
@@ -570,6 +581,8 @@ extern "C" {
         GtkWidget *entry = gtk_bin_get_child(GTK_BIN(combo));
         g_signal_connect_after(G_OBJECT(entry), "focus-out-event",
                                G_CALLBACK(_ufarray_entry_changed), object);
+        g_signal_connect_after(G_OBJECT(entry), "activate",
+                               G_CALLBACK(_ufarray_entry_activate), object);
         return _ufarray_combo_box_new(object, combo);
     }
 
