@@ -3,7 +3,7 @@
  * UFRaw - Unidentified Flying Raw converter for digital camera images
  *
  * ufraw.h - Common definitions for UFRaw.
- * Copyright 2004-2014 by Udi Fuchs
+ * Copyright 2004-2015 by Udi Fuchs
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -253,7 +253,7 @@ typedef struct {
     double exposure, saturation, black; /* black is only used in CMD */
     int ExposureNorm;
     int restoreDetails, clipHighlights;
-    int autoExposure, autoBlack, autoCrop;
+    int autoExposure, autoBlack, fullCrop, autoCrop;
     int BaseCurveIndex, BaseCurveCount;
     CurveData BaseCurve[max_curves];
     int curveIndex, curveCount;
