@@ -14,23 +14,8 @@
 #include <glib/gi18n.h>
 #include <errno.h>	/* for errno */
 #include <string.h>
-#ifdef HAVE_LCMS2
 #include <lcms2.h>
-#else
-#include <lcms.h>
-typedef DWORD cmsUInt32Number;
-static LCMSBOOL cmsSaveProfileToMem(cmsHPROFILE hProfile, void *MemPtr,
-                                    cmsUInt32Number *BytesNeeded)
-{
-    size_t _BytesNeeded;
-    LCMSBOOL retval;
-
-    retval = _cmsSaveProfileToMem(hProfile, MemPtr, &_BytesNeeded);
-    if (BytesNeeded)
-        *(BytesNeeded) = (cmsUInt32Number) _BytesNeeded;
-    return retval;
-}
-#endif
+#include "ufraw_colorspaces.h"
 #ifdef HAVE_LIBTIFF
 #include <tiffio.h>
 #endif
@@ -422,7 +407,7 @@ int ufraw_write_image(ufraw_data *uf)
                                   uf->conf->outputFilename);
             }
         } else if (uf->conf->profileIndex[out_profile] == 1) { // Embed sRGB.
-            cmsHPROFILE hOutProfile = cmsCreate_sRGBProfile();
+            cmsHPROFILE hOutProfile = uf_colorspaces_create_srgb_profile();
             cmsUInt32Number len = 0;
             cmsSaveProfileToMem(hOutProfile, 0, &len); // Calculate len.
             if (len > 0) {
@@ -495,7 +480,7 @@ int ufraw_write_image(ufraw_data *uf)
                                   uf->conf->outputFilename);
             }
         } else if (uf->conf->profileIndex[out_profile] == 1) { // Embed sRGB.
-            cmsHPROFILE hOutProfile = cmsCreate_sRGBProfile();
+            cmsHPROFILE hOutProfile = uf_colorspaces_create_srgb_profile();
             cmsUInt32Number len = 0;
             cmsSaveProfileToMem(hOutProfile, 0, &len); // Calculate len.
             if (len > 0) {
@@ -587,7 +572,7 @@ int ufraw_write_image(ufraw_data *uf)
                                       uf->conf->outputFilename);
                 }
             } else if (uf->conf->profileIndex[out_profile] == 1) { // Embed sRGB.
-                cmsHPROFILE hOutProfile = cmsCreate_sRGBProfile();
+                cmsHPROFILE hOutProfile = uf_colorspaces_create_srgb_profile();
                 cmsUInt32Number len = 0;
                 cmsSaveProfileToMem(hOutProfile, 0, &len); // Calculate len.
                 if (len > 0) {
